game_qu.pygame_abstraction API documentation
Description: Holds all the code that abstracts dealing with pygame code from the rest of the game engine code. It does this by having an interface with many …

# Module `game_qu.pygame_abstraction`

Holds all the code that abstracts dealing with pygame code from the rest of the game engine code. It does this by having an interface with many functions that deal with the pygame code.

Expand source code

    """Holds all the code that abstracts dealing with pygame code from the rest of the game engine code. It does this by having
    an interface with many functions that deal with the pygame code."""

## Sub-modules

`game_qu.pygame_abstraction.keys`

  Contains all the keys that the user can use. Feel free to add more by downloading the code off of GitHub and manually adding them

`game_qu.pygame_abstraction.utility_functions`
`game_qu.pygame_abstraction.variables`

  Has all the variables that are important for the pygame code to run